@@ -1,7 +1,5 @@
 package Cache::FastMmap;
 
-use Data::Dumper;
-
 =head1 NAME
 
 Cache::FastMmap - Uses an mmap'ed file to act as a shared memory interprocess cache
@@ -166,8 +164,10 @@ comparisons to other modules.
 
 Cache::FastMmap uses mmap to map a file as the shared cache space,
 and fcntl to do page locking. This means it should work on most
-UNIX like operating systems, but will not work on Windows or
-Win32 like environments.
+UNIX like operating systems.
+
+Ash Berlin has written a Win32 layer using MapViewOfFile et al. to 
+provide support for Win32 platform.
 
 =head1 MEMORY SIZE
 
@@ -180,6 +180,69 @@ However, the OS will think your process is quite large, which might
 mean you hit some BSD::Resource or 'ulimits' you set previously that you
 thought were sane, but aren't anymore, so be aware.
 
+=head1 CACHE FILES AND OS ISSUES
+
+Because Cache::FastMmap uses an mmap'ed file, when you put values into
+the cache, you are actually "dirtying" pages in memory that belong to
+the cache file. Your OS will want to write those dirty pages back to
+the file on the actual physical disk, but the rate it does that at is
+very OS dependent.
+
+In Linux, you have some control over how the OS writes those pages
+back using a number of parameters in /proc/sys/vm
+
+  dirty_background_ratio
+  dirty_expire_centisecs
+  dirty_ratio
+  dirty_writeback_centisecs
+
+How you tune these depends heavily on your setup.
+
+As an interesting point, if you use a highmem linux kernel, a change
+between 2.6.16 and 2.6.20 made the kernel flush memory a LOT more.
+There's details in this kernel mailing list thread:
+L<http://www.uwsg.iu.edu/hypermail/linux/kernel/0711.3/0804.html>
+
+In most cases, people are not actually concerned about the persistence
+of data in the cache, and so are happy to disable writing of any cache
+data back to disk at all. Baically what they want is an in memory only
+shared cache. The best way to do that is to use a "tmpfs" filesystem
+and put all cache files on there.
+
+For instance, all our machines have a /tmpfs mount point that we
+create in /etc/fstab as:
+
+  none /tmpfs tmpfs defaults,noatime,size=1000M 0 0
+
+And we put all our cache files on there. The tmpfs filesystem is smart
+enough to only use memory as required by files actually on the tmpfs,
+so making it 1G in size doesn't actually use 1G of memory, it only uses
+as much as the cache files we put on it. In all cases, we ensure that
+we never run out of real memory, so the cache files effectively act 
+just as named access points to shared memory.
+
+Some people have suggested using anonymous mmaped memory. Unfortunately
+we need a file descriptor to do the fcntl locking on, so we'd have
+to create a separate file on a filesystem somewhere anyway. It seems
+easier to just create an explicit "tmpfs" filesystem.
+
+=head1 PAGE SIZE AND KEY/VALUE LIMITS
+
+To reduce lock contention, Cache::FastMmap breaks up the file
+into pages. When you get/set a value, it hashes the key to get a page,
+then locks that page, and uses a hash table within the page to
+get/store the actual key/value pair.
+
+One consequence of this is that you cannot store values larger than
+a page in the cache at all. Attempting to store values larger than
+a page size will fail (the set() function will return false).
+
+Also keep in mind that each page has it's own hash table, and that we
+store the key and value data of each item. So if you are expecting to
+store large values and/or keys in the cache, you should use page sizes
+that are definitely larger than your largest key + value size + a few
+kbytes for the overhead.
+
 =head1 USAGE
 
 Because the cache uses shared memory through an mmap'd file, you have
@@ -192,11 +255,13 @@ two main ways to do this:
 
 Create the cache in the parent process, and then when it forks, each
 child will inherit the same file descriptor, mmap'ed memory, etc and
-just work.
+just work. (BEWARE: This works just under UNIX as Win32 has no 
+concept of forking)
 
 =item *
 
-Explicitly connect up in each forked child to the share file
+Explicitly connect up in each forked child to the share file. (This is
+the only possible way under Win32)
 
 =back
 
@@ -221,31 +286,11 @@ use 5.006;
 use strict;
 use warnings;
 use bytes;
+
+our $VERSION = '1.30';
+
 use Cache::FastMmap::CImpl;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Cache::FastMmap ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-	
-);
-
-our $VERSION = '1.14';
-
 use constant FC_ISDIRTY => 1;
 # }}}
 
@@ -259,7 +304,9 @@ Basic global parameters are:
 
 =item * B<share_file>
 
-File to mmap for sharing of data (default: /tmp/sharefile)
+File to mmap for sharing of data.
+default on unix: /tmp/sharefile-$pid-$time-$random
+default on windows: %TEMP%\sharefile-$pid-$time-$random
 
 =item * B<init_file>
 
@@ -277,6 +324,26 @@ the the cache file in an inconsistent state.
 Store values as raw binary data rather than using Storable to free/thaw
 data structures (default: 0)
 
+=item * B<compress>
+
+Compress the value (but not the key) before storing into the cache. If
+you set this to 1, the module will attempt to require the Compress::Zlib
+module and then use the memGzip() function on the value data before
+storing into the cache, and memGunzip() when retrieving data from the
+cache. Some initial testing shows that the uncompressing tends to be
+very fast, though the compressing can be quite slow, so it's probably
+best to use this option only if you know values in the cache are long
+lived and have a high hit rate. (default: 0)
+
+=item * B<enable_stats>
+
+Enable some basic statistics capturing. When enabled, every read to
+the cache is counted, and every read to the cache that finds a value
+in the cache is also counted. You can then retrieve these values
+via the get_statistics() call. This causes every read action to
+do a write on a page, which can cause some more IO, so it's
+disabled by default. (default: 0)
+
 =item * B<expire_time>
 
 Maximum time to hold values in the cache in seconds. A value of 0
@@ -374,15 +441,40 @@ the I<read_cb>
 
 Either 'write_back' or 'write_through'. (default: write_through)
 
+=item * B<allow_recursive>
+
+If you're using a callback function, then normally the cache is not
+re-enterable, and attempting to call a get/set on the cache will
+cause an error. By setting this to one, the cache will unlock any
+pages before calling the callback. During the unlock time, other
+processes may change data in current cache page, causing possible
+unexpected effects. You shouldn't set this unless you know you
+want to be able to recall to the cache within a callback.
+(default: 0)
+
 =item * B<empty_on_exit>
 
 When you have 'write_back' mode enabled, then
 you really want to make sure all values from the cache are expunged
-when your program exits so any changes are written back. This is a
-bit tricky, because we don't know if you're in a child, so you
-must ensure that the parent process either explicitly calls
-I<empty()> or that this flag is set to true when the parent connects
-to the cache, and false in all the children
+when your program exits so any changes are written back.
+
+The trick is that we only want to do this in the parent process,
+we don't want any child processes to empty the cache when they exit.
+So if you set this, it takes the PID via $$, and only calls
+empty in the DESTROY method if $$ matches the pid we captured
+at the start. (default: 0)
+
+=item * B<unlink_on_exit>
+
+Unlink the share file when the cache is destroyed.
+
+As with empty_on_exit, this will only unlink the file if the
+DESTROY occurs in the same PID that the cache was created in
+so that any forked children don't unlink the file.
+
+This value defaults to 1 if the share_file specified does
+not already exist. If the share_file specified does already
+exist, it defaults to 0.
 
 =back
 
@@ -390,16 +482,32 @@ to the cache, and false in all the children
 sub new {
   my $Proto = shift;
   my $Class = ref($Proto) || $Proto;
-  my %Args = @_;
+
+  # If first item is a hash ref, use it as arguments
+  my %Args = ref($_[0]) eq 'HASH' ? %{shift()} : @_;
 
   my $Self = {};
   bless ($Self, $Class);
 
   # Work out cache file and whether to init
-  my $share_file = $Self->{share_file}
-    = $Args{share_file} || '/tmp/sharefile';
-  my $init_file = $Args{init_file} || 0;
-  my $test_file = $Args{test_file} || 0;
+  my $share_file = $Args{share_file};
+  if (!$share_file) {
+    my $tmp_dir = $ENV{TMPDIR} || "/tmp";
+    my $win_tmp_dir = $ENV{TEMP} || "c:\\";
+    $share_file = ($^O eq "MSWin32" ? "$win_tmp_dir\\sharefile" : "$tmp_dir/sharefile");
+    $share_file .= "-" . $$ . "-" . time . "-" . int(rand(100000));
+  }
+  !ref($share_file) || die "share_file argument was a reference";
+  $Self->{share_file} = $share_file;
+
+  my $init_file = $Args{init_file} ? 1 : 0;
+  my $test_file = $Args{test_file} ? 1 : 0;
+  my $enable_stats = $Args{enable_stats} ? 1 : 0;
+
+  # Worth out unlink default if not specified
+  if (!exists $Args{unlink_on_exit}) {
+    $Args{unlink_on_exit} = -f($share_file) ? 0 : 1;
+  }
 
   # Storing raw/storable values?
   my $raw_values = $Self->{raw_values} = int($Args{raw_values} || 0);
@@ -410,11 +518,17 @@ sub new {
       || die "Could not load Storable module: $@";
   }
 
+  # Compress stored values?
+  my $compress = $Self->{compress} = int($Args{compress} || 0);
+
+  # Need Compress::Zlib module if using compression
+  if ($compress) {
+    eval "use Compress::Zlib; 1;"
+      || die "Could not load Compress::Zlib module: $@";
+  }
+
   # Work out expiry time in seconds
-  my $expire_time = $Args{expire_time} || 0;
-  my %Times = (m => 60, h => 60*60, d => 24*60*60);
-  $expire_time *= $Times{$1} if $expire_time =~ s/([mhd])$//i;
-  $Self->{expire_time} = $expire_time = int($expire_time);
+  my $expire_time = $Self->{expire_time} = parse_expire_time($Args{expire_time});
 
   # Function rounds to the nearest power of 2
   sub RoundPow2 { return int(2 ** int(log($_[0])/log(2)) + 0.1); }
@@ -469,8 +583,13 @@ sub new {
   my $write_back = ($Args{write_action} || 'write_through') eq 'write_back';
   @$Self{qw(context read_cb write_cb delete_cb)}
     = @Args{qw(context read_cb write_cb delete_cb)};
-  @$Self{qw(empty_on_exit cache_not_found write_back)}
-    = (@Args{qw(empty_on_exit cache_not_found)}, $write_back);
+  @$Self{qw(cache_not_found allow_recursive write_back)}
+    = (@Args{qw(cache_not_found allow_recursive)}, $write_back);
+  @$Self{qw(empty_on_exit unlink_on_exit enable_stats)}
+    = (@Args{qw(empty_on_exit unlink_on_exit)}, $enable_stats);
+
+  # Save pid
+  $Self->{pid} = $$;
 
   # Initialise C cache code
   my $Cache = Cache::FastMmap::CImpl::fc_new();
@@ -491,6 +610,7 @@ sub new {
   $Cache->fc_set_param('expire_time', $expire_time);
   $Cache->fc_set_param('share_file', $share_file);
   $Cache->fc_set_param('start_slots', $start_slots);
+  $Cache->fc_set_param('enable_stats', $enable_stats);
 
   # And initialise it
   $Cache->fc_init();
@@ -523,7 +643,17 @@ sub get {
   if (!$Found && (my $read_cb = $Self->{read_cb})) {
 
     # Callback to read from underlying data store
+    # (unlock page first if we allow recursive calls
+    $Cache->fc_unlock() if $Self->{allow_recursive};
     $Val = eval { $read_cb->($Self->{context}, $_[1]); };
+    my $Err = $@;
+    $Cache->fc_lock($HashPage) if $Self->{allow_recursive};
+
+    # Pass on any error
+    if ($Err) {
+      $Cache->fc_unlock();
+      die $Err;
+    }
 
     # If we found it, or want to cache not-found, store back into our cache
     if (defined $Val || $Self->{cache_not_found}) {
@@ -533,13 +663,14 @@ sub get {
 
       # If not using raw values, use freeze() to turn data 
       $Val = freeze(\$Val) if !$Self->{raw_values};
+      $Val = Compress::Zlib::memGzip($Val) if $Self->{compress};
 
       # Get key/value len (we've got 'use bytes'), and do expunge check to
       #  create space if needed
-      my $KVLen = length($_[1]) + length($Val);
+      my $KVLen = length($_[1]) + (defined($Val) ? length($Val) : 0);
       $Self->_expunge_page(2, 1, $KVLen);
 
-      $Cache->fc_write($HashSlot, $_[1], $Val, 0);
+      $Cache->fc_write($HashSlot, $_[1], $Val, -1, 0);
     }
   }
 
@@ -548,9 +679,8 @@ sub get {
   $Cache->fc_unlock() unless $_[2] && $_[2]->{skip_unlock};
 
   # If not using raw values, use thaw() to turn data back into object
-  if (!$Self->{raw_values}) {
-    $Val = ${thaw($Val)} if defined $Val;
-  }
+  $Val = Compress::Zlib::memGunzip($Val) if defined($Val) && $Self->{compress};
+  $Val = ${thaw($Val)} if defined($Val) && !$Self->{raw_values};
 
   return $Val;
 }
@@ -563,27 +693,36 @@ I<%Options> is optional, and is used by get_and_set() to control
 the locking behaviour. For now, you should probably ignore it
 unless you read the code to understand how it works
 
+This method returns true if the value was stored in the cache,
+false otherwise. See the PAGE SIZE AND KEY/VALUE LIMITS section
+for more details.
+
 =cut
 sub set {
   my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
 
+  # If not using raw values, use freeze() to turn data 
+  my $Val = $Self->{raw_values} ? $_[2] : freeze(\$_[2]);
+  $Val = Compress::Zlib::memGzip($Val) if $Self->{compress};
+
+  # Get opts, make compatiable with Cache::Cache interface
+  my $Opts = defined($_[3]) ? (ref($_[3]) ? $_[3] : { expire_time => $_[3] }) : undef;
+  my $expire_seconds = defined($Opts && $Opts->{expire_time}) ? parse_expire_time($Opts->{expire_time}) : -1;
+
   # Hash value, lock page
   my ($HashPage, $HashSlot) = $Cache->fc_hash($_[1]);
-  $Cache->fc_lock($HashPage) unless $_[3] && $_[3]->{skip_lock};
+  $Cache->fc_lock($HashPage) unless $Opts && $Opts->{skip_lock};
 
   # Are we doing writeback's? If so, need to mark as dirty in cache
   my $write_back = $Self->{write_back};
 
-  # If not using raw values, use freeze() to turn data 
-  my $Val = $Self->{raw_values} ? $_[2] : freeze(\$_[2]);
-
   # Get key/value len (we've got 'use bytes'), and do expunge check to
   #  create space if needed
-  my $KVLen = length($_[1]) + length($Val);
+  my $KVLen = length($_[1]) + (defined($Val) ? length($Val) : 0);
   $Self->_expunge_page(2, 1, $KVLen);
 
   # Now store into cache
-  my $DidStore = $Cache->fc_write($HashSlot, $_[1], $Val, $write_back ? FC_ISDIRTY : 0);
+  my $DidStore = $Cache->fc_write($HashSlot, $_[1], $Val, $expire_seconds, $write_back ? FC_ISDIRTY : 0);
 
   # Unlock page
   $Cache->fc_unlock();
@@ -615,8 +754,13 @@ can just use:
 
   $Cache->get_and_set($Key, sub { return ++$_[1]; });
 
-The return value from this function is the new value stored back
-into the cache.
+In scalar context, the return value from this function is the *new* value
+stored back into the cache.
+
+In list context, a two item array is returned; the new value stored
+back into the cache and a boolean that's true if the value was stored
+in the cache, false otherwise. See the PAGE SIZE AND KEY/VALUE LIMITS
+section for more details.
 
 Notes:
 
@@ -629,9 +773,8 @@ operations lock the page and you may end up with a dead lock!
 
 =item *
 
-Make sure your sub does not die/throw an exception, otherwise the
-unlocking code will be skipped. You can protect yourself by
-wrapping everything in your sub in an C<eval { }>
+If your sub does a die/throws an exception, this will be caught
+to allow the page to be unlocked, and then rethrown (1.15 onwards)
 
 =back
 
@@ -640,23 +783,32 @@ sub get_and_set {
   my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
 
   my $Value = $Self->get($_[1], { skip_unlock => 1 });
-  $Value = $_[2]->($_[1], $Value);
-  $Self->set($_[1], $Value, { skip_lock => 1 });
+  eval { $Value = $_[2]->($_[1], $Value); };
+  my $Err = $@;
+  my $DidStore = $Self->set($_[1], $Value, { skip_lock => 1 });
+  die $Err if $Err;
 
-  return $Value;
+  return wantarray ? ($Value, $DidStore) : $Value;
 }
 
-=item I<remove($Key)>
+=item I<remove($Key, [ \%Options ])>
 
 Delete the given key from the cache
 
+I<%Options> is optional, and is used by get_and_remove() to control
+the locking behaviour. For now, you should probably ignore it
+unless you read the code to understand how it works
+
 =cut
 sub remove {
   my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
 
   # Hash value, lock page, read result
   my ($HashPage, $HashSlot) = $Cache->fc_hash($_[1]);
-  $Cache->fc_lock($HashPage);
+
+  # Lock is done only if we're not in the middle of a get_and_remove() operation.
+  $Cache->fc_lock($HashPage) unless $_[2] && $_[2]->{skip_lock};
+
   my ($DidDel, $Flags) = $Cache->fc_delete($HashSlot, $_[1]);
   $Cache->fc_unlock();
 
@@ -670,6 +822,23 @@ sub remove {
   return $DidDel;
 }
 
+=item I<get_and_remove($Key)>
+
+Atomically retrieve value of a Key while removing it from the cache.
+
+The page is locked while retrieving the $Key and is unlocked only after
+the value is removed, thus guaranteeing the value stored by someone else
+isn't removed by us.
+
+=cut
+sub get_and_remove {
+  my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
+
+  my $Value = $Self->get($_[1], { skip_unlock => 1 });
+  my $DidDel = $Self->remove($_[1], { skip_lock => 1 });
+  return wantarray ? ($Value, $DidDel) : $Value;
+}
+
 =item I<clear()>
 
 Clear all items from the cache
@@ -732,14 +901,52 @@ sub get_keys {
 
   my $Mode = $_[1] || 0;
   return $Cache->fc_get_keys($Mode)
-    if $Mode <= 1 || ($Mode == 2 && $Self->{raw_values});
+    if $Mode <= 1 || ($Mode == 2 && $Self->{raw_values} && !$Self->{compress});
 
   # If we're getting values as well, and they're not raw, unfreeze them
   my @Details = $Cache->fc_get_keys(2);
-  for (@Details) { $_->{value} = ${thaw($_->{value})}; }
+  for (@Details) {
+    if (defined(my $Value = $_->{value})) {
+      $Value = Compress::Zlib::memGunzip($Value) if $Self->{compress};
+      $Value = ${thaw($Value)} if !$Self->{raw_values};
+      $_->{value} = $Value;
+    }
+  }
   return @Details;
 }
 
+=item I<get_statistics($Clear)>
+
+Returns a two value list of (nreads, nreadhits). This
+only works if you passed enable_stats in the constructor
+
+nreads is the total number of read attempts done on the
+cache since it was created
+
+nreadhits is the total number of read attempts done on
+the cache since it was created that found the key/value
+in the cache
+
+If $Clear is true, the values are reset immediately after
+they are retrieved
+
+=cut
+sub get_statistics {
+  my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
+  my $Clear = $_[1];
+
+  my ($NReads, $NReadHits) = (0, 0);
+  for (0 .. $Self->{num_pages}-1) {
+    $Cache->fc_lock($_);
+    my ($PNReads, $PNReadHits) = $Cache->fc_get_page_details();
+    $NReads += $PNReads;
+    $NReadHits += $PNReadHits;
+    $Cache->fc_reset_page_details() if $Clear;
+    $Cache->fc_unlock();
+  }
+  return ($NReads, $NReadHits);
+}
+
 =item I<multi_get($PageKey, [ $Key1, $Key2, ... ])>
 
 The two multi_xxx routines act a bit differently to the
@@ -796,7 +1003,8 @@ sub multi_get {
     next unless $Found;
 
     # If not using raw values, use thaw() to turn data back into object
-    $Val = ${thaw($Val)} unless $Self->{raw_values};
+    $Val = Compress::Zlib::memGunzip($Val) if defined($Val) && $Self->{compress};
+    $Val = ${thaw($Val)} if defined($Val) && !$Self->{raw_values};
 
     # Save to return
     $KVs{$_} = $Val;
@@ -808,7 +1016,7 @@ sub multi_get {
   return \%KVs;
 }
 
-=item I<multi_set($PageKey, { $Key1 => $Value1, $Key2 => $Value2, ... })>
+=item I<multi_set($PageKey, { $Key1 => $Value1, $Key2 => $Value2, ... }, [ \%Options ])>
 
 Store specified key/value pair into cache
 
@@ -816,6 +1024,10 @@ Store specified key/value pair into cache
 sub multi_set {
   my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
 
+  # Get opts, make compatiable with Cache::Cache interface
+  my $Opts = defined($_[3]) ? (ref($_[3]) ? $_[3] : { expire_time => $_[3] }) : undef;
+  my $expire_seconds = defined($Opts && $Opts->{expire_time}) ? parse_expire_time($Opts->{expire_time}) : -1;
+
   # Hash page key value, lock page
   my ($HashPage, $HashSlot) = $Cache->fc_hash($_[1]);
   $Cache->fc_lock($HashPage);
@@ -826,6 +1038,7 @@ sub multi_set {
 
     # If not using raw values, use freeze() to turn data 
     $Val = freeze(\$Val) unless $Self->{raw_values};
+    $Val = Compress::Zlib::memGzip($Val) if $Self->{compress};
 
     # Get key/value len (we've got 'use bytes'), and do expunge check to
     #  create space if needed
@@ -835,7 +1048,7 @@ sub multi_set {
 
     # Now hash key and store into page
     (undef, $HashSlot) = $Cache->fc_hash($FinalKey);
-    $Cache->fc_write($HashSlot, $FinalKey, $Val, 0);
+    my $DidStore = $Cache->fc_write($HashSlot, $FinalKey, $Val, $expire_seconds, 0);
   }
 
   # Unlock page
@@ -897,11 +1110,19 @@ sub _expunge_page {
   }
 }
 
+sub parse_expire_time {
+  my $expire_time = shift || '';
+  return 1 if $expire_time eq 'now';
+  return 0 if $expire_time eq 'never';
+  my %Times = ('' => 1, s => 1, m => 60, h => 60*60, d => 24*60*60, w => 7*24*60*60);
+  return $expire_time =~ /^(\d+)\s*([mhdws]?)/i ? $1 * $Times{$2} : 0;
+}
+
 sub DESTROY {
   my ($Self, $Cache) = ($_[0], $_[0]->{Cache});
 
-  # Expunge all entries on exit if requested
-  if ($Self->{empty_on_exit} && $Cache) {
+  # Expunge all entries on exit if requested and in parent process
+  if ($Self->{empty_on_exit} && $Cache && $Self->{pid} == $$) {
     $Self->empty();
   }
 
@@ -910,6 +1131,13 @@ sub DESTROY {
     $Cache = undef;
     delete $Self->{Cache};
   }
+
+  unlink($Self->{share_file})
+    if $Self->{unlink_on_exit} && $Self->{pid} == $$;
+}
+
+sub CLONE {
+  die "Cache::FastMmap does not support threads sorry";
 }
 
 1;
@@ -918,6 +1146,47 @@ __END__
 
 =back
 
+=head1 INCOMPATIABLE CHANGES
+
+=over 4
+
+=item From 1.15
+
+=over 4
+
+=item *
+
+Default share_file name is no-longer /tmp/sharefile, but /tmp/sharefile-$pid-$time.
+This ensures that different runs/processes don't interfere with each other, but
+means you may not connect up to the file you expect. You should be choosing an
+explicit name in most cases.
+
+On Unix systems, you can pass in the environment variable TMPDIR to
+override the default directory of /tmp
+
+=item *
+
+The new option unlink_on_exit defaults to true if you pass a filename for the
+share_file which doesn't already exist. This means if you have one process that
+creates the file, and another that expects the file to be there, by default it
+won't be.
+
+Otherwise the defaults seem sensible to cleanup unneeded share files rather than
+leaving them around to accumulate.
+
+=item After 1.28
+
+=over 4
+
+=item *
+
+Default share_file name is no longer /tmp/sharefile-$pid-$time 
+but /tmp/sharefile-$pid-$time-$random.
+
+=back
+
+=back
+
 =head1 SEE ALSO
 
 L<MLDBM::Sync>, L<IPC::MM>, L<Cache::FileCache>, L<Cache::SharedMemoryCache>,
@@ -929,11 +1198,11 @@ L<http://cpan.robm.fastmail.fm/cachefastmmap/>
 
 =head1 AUTHOR
 
-Rob Mueller E<lt>L<mailto:cpan@robm.fastmail.fm>E<gt>
+Rob Mueller L<mailto:cpan@robm.fastmail.fm>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2006 by FastMail IP Partners
+Copyright (C) 2003-2008 by FastMail IP Partners
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
